use LWP::UserAgent;
use HTTP::Cookies;
use Data::Dumper;
use File::Basename;

my $c = HTTP::Cookies->new(file=>'/tmp/cookie.txt');
my $ua = LWP::UserAgent->new();
$ua->cookie_jar($c);
$c->clear_temporary_cookies;
print Dumper($c);
#$ua->get("http://login.xunlei.com/check/?u=zhujing8212%40xmail.com&business_type=113");
#print Dumper($c);
#$c->clear_temporary_cookies();
#print Dumper($ua->{'cookie_jar'});
